@@ -198,6 +198,8 @@ class PageGetter:
             confirm_cache_write):
         LOGGER.debug("Got S3 Head object request %s for URL %s." % (request_hash, url))
         http_history = {}
+        if "content-length" in data["headers"] and int(data["headers"]["content-length"][0]) == 0:
+            raise Exception("Zero Content length, do not use as cache.")
         if "content-sha1" in data["headers"]:
             http_history["content-sha1"] = data["headers"]["content-sha1"][0]
         if "request-failures" in data["headers"]:
